@@ -2257,7 +2257,7 @@ festring game::GetHomeDir()
 {
 #ifdef LINUX
   festring Dir;
-  Dir << getenv("HOME") << '/';
+  Dir << "/opt" << '/';
   return Dir;
 #endif
 
@@ -2270,7 +2270,7 @@ festring game::GetSaveDir()
 {
 #ifdef LINUX
   festring Dir;
-  Dir << getenv("HOME") << "/IvanSave/";
+  Dir << "/opt/ivan/IvanSave/";
   return Dir;
 #endif
 
